from typing import Optional

from bot_api.abc.dto_abc import DtoABC
from bot_data.model.auth_role_enum import AuthRoleEnum


class AuthUserDTO(DtoABC):

    def __init__(
            self,
            id: int,
            first_name: str,
            last_name: str,
            email: str,
            password: str,
            confirmation_id: Optional[str],
            auth_role: AuthRoleEnum,
            user_id: Optional[int],
    ):
        DtoABC.__init__(self)

        self._id = id
        self._first_name = first_name
        self._last_name = last_name
        self._email = email
        self._password = password
        self._is_confirmed = confirmation_id is None
        self._auth_role = auth_role
        self._user_id = user_id
        
    @property
    def id(self) -> int:
        return self._id

    @property
    def first_name(self) -> str:
        return self._first_name

    @first_name.setter
    def first_name(self, value: str):
        self._first_name = value

    @property
    def last_name(self) -> str:
        return self._last_name

    @last_name.setter
    def last_name(self, value: str):
        self._last_name = value

    @property
    def email(self) -> str:
        return self._email

    @email.setter
    def email(self, value: str):
        self._email = value

    @property
    def password(self) -> str:
        return self._password

    @password.setter
    def password(self, value: str):
        self._password = value

    @property
    def is_confirmed(self) -> Optional[str]:
        return self._is_confirmed

    @is_confirmed.setter
    def is_confirmed(self, value: Optional[str]):
        self._is_confirmed = value

    @property
    def auth_role(self) -> AuthRoleEnum:
        return self._auth_role

    @auth_role.setter
    def auth_role(self, value: AuthRoleEnum):
        self._auth_role = value

    @property
    def user_id(self) -> Optional[int]:
        return self._user_id

    @user_id.setter
    def user_id(self, value: Optional[int]):
        self._user_id = value

    def from_dict(self, values: dict):
        self._id = values['id']
        self._first_name = values['firstName']
        self._last_name = values['lastName']
        self._email = values['email']
        self._password = values['password']
        self._is_confirmed = values['isConfirmed']
        self._auth_role = values['authRole']
        self._user_id = values['userId']

    def to_dict(self) -> dict:
        return {
            'id': self._id,
            'firstName': self._first_name,
            'lastName': self._last_name,
            'email': self._email,
            'password': self._password,
            'isConfirmed': self._is_confirmed,
            'authRole': self._auth_role.value,
            'userId': self._user_id,
        }
